// src/YouVisitIWC/YouVisitIWC.tsx
import { useState as useState3, useEffect as useEffect2 } from "react";

// src/YouVisitIWC/config.ts
var YV_SOURCE = "https://www.youvisit.com/tour/Embed/js3";
var DEFAULT_DESCRIPTION = "Interactive Image Element";
var DEFAULT_UPLOAD_DATE = "2020-03-31T08:00:00+08:00";
var PUBLISHER_CONFIG = {
  name: "EAB",
  logo: {
    url: "https://attachment.eab.com/wp-content/uploads/2019/07/EAB-Logo-RGB.png",
    width: 500,
    height: 193
  }
};

// src/YouVisitIWC/components/JsonLd.tsx
import { jsx } from "react/jsx-runtime";
var JsonLd = ({ data }) => /* @__PURE__ */ jsx(
  "script",
  {
    type: "application/ld+json",
    dangerouslySetInnerHTML: { __html: JSON.stringify(data) }
  }
);
var JsonLd_default = JsonLd;

// src/YouVisitIWC/utils.ts
var generateJsonLdData = (title, description, thumb, uploadDate) => ({
  "@context": "https://schema.org",
  "@type": "VideoObject",
  name: title,
  description,
  thumbnailUrl: thumb,
  uploadDate,
  publisher: {
    "@type": "Organization",
    name: PUBLISHER_CONFIG.name,
    logo: {
      "@type": "ImageObject",
      ...PUBLISHER_CONFIG.logo
    }
  },
  contentUrl: "url of actual tour",
  embedUrl: "url where the tour has been placed",
  interactionCount: "locations.views"
});
var generateAnchorProps = (props) => {
  const baseProps = {
    href: "https://www.youvisit.com",
    title: props.title,
    "data-inst": props.institution,
    "data-link-type": props.linkType,
    "data-loc": props.location,
    "data-platform": "v",
    "data-type": props.type,
    "data-hover-width": props.hoverWidth,
    "data-hover-height": props.hoverHeight,
    "data-image-width": props.iwcWidth,
    "data-image-height": props.iwcHeight
  };
  if (props.stopId) {
    baseProps["data-stopid"] = props.stopId;
  }
  if (props.type !== "hover-panel") {
    baseProps["data-type"] = props.type;
  }
  return baseProps;
};
var generateDataAttributesString = (anchorProps) => {
  const entries = Object.entries(anchorProps).filter(
    ([key]) => key.startsWith("data-")
  );
  return entries.map(
    ([key, value], index) => `    ${index === 0 ? "?" : "&"}${key}=${value}`
  ).join("\n");
};

// src/hooks/useScript.ts
import { useState, useEffect, useRef } from "react";
function useScript(src, options = {}) {
  const [status, setStatus] = useState("loading");
  const optionsRef = useRef(options);
  useEffect(() => {
    let script = document.querySelector(
      `script[src="${src}"]`
    );
    if (script) {
      const domStatus = script.getAttribute("data-status");
      if (domStatus) {
        setStatus(domStatus);
        return;
      }
      script.setAttribute("data-status", "ready");
      setStatus("ready");
      return;
    }
    script = document.createElement("script");
    script.src = src;
    script.async = true;
    script.setAttribute("data-status", "loading");
    document.body.appendChild(script);
    const handleScriptLoad = () => {
      script.setAttribute("data-status", "ready");
      setStatus("ready");
      removeEventListeners();
    };
    const handleScriptError = () => {
      script.setAttribute("data-status", "error");
      setStatus("error");
      removeEventListeners();
    };
    const removeEventListeners = () => {
      script.removeEventListener("load", handleScriptLoad);
      script.removeEventListener("error", handleScriptError);
    };
    script.addEventListener("load", handleScriptLoad);
    script.addEventListener("error", handleScriptError);
    const removeOnUnmount = optionsRef.current.removeOnUnmount;
    return () => {
      if (removeOnUnmount === true) {
        script.remove();
        removeEventListeners();
      }
    };
  }, [src]);
  return status;
}

// src/YouVisitIWC/YouVisitIWC.tsx
import { PrismLight as SyntaxHighlighter } from "react-syntax-highlighter";
import markup from "react-syntax-highlighter/dist/cjs/languages/prism/markup";
import { coldarkCold } from "react-syntax-highlighter/dist/cjs/styles/prism";

// src/YouVisitIWC/components/copy-to-clipboard.tsx
import { useState as useState2 } from "react";

// src/YouVisitIWC/YouVisitIWC.module.css
var YouVisitIWC_default = {};

// src/YouVisitIWC/components/copy-to-clipboard.tsx
import { jsx as jsx2, jsxs } from "react/jsx-runtime";
var CopyToClipboard = ({
  textData,
  buttonTextPreCopy = "Copy to clipboard",
  buttonTextPostCopy = "Copied!"
}) => {
  const [copied, setCopied] = useState2(false);
  const copyToClipboard = async () => {
    if (navigator.clipboard) {
      try {
        await navigator.clipboard.writeText(textData);
        setCopied(true);
      } catch (err) {
        console.error("Failed to copy with Clipboard API:", err);
        fallbackCopyToClipboard();
      }
    } else {
      fallbackCopyToClipboard();
    }
    setTimeout(() => {
      setCopied(false);
    }, 500);
  };
  const fallbackCopyToClipboard = () => {
    try {
      const textArea = document.createElement("textarea");
      textArea.value = textData;
      textArea.style.top = "0";
      textArea.style.left = "0";
      textArea.style.position = "fixed";
      textArea.style.opacity = "0";
      document.body.appendChild(textArea);
      textArea.focus();
      textArea.select();
      const successful = document.execCommand("copy");
      document.body.removeChild(textArea);
      if (successful) {
        setCopied(true);
      } else {
        console.error("Fallback clipboard copy failed");
      }
    } catch (err) {
      console.error("Fallback clipboard copy error:", err);
    }
  };
  return /* @__PURE__ */ jsx2("div", { className: YouVisitIWC_default.container, children: /* @__PURE__ */ jsxs("button", { onClick: copyToClipboard, className: YouVisitIWC_default.button, children: [
    /* @__PURE__ */ jsx2("span", { children: copied ? buttonTextPostCopy : buttonTextPreCopy }),
    /* @__PURE__ */ jsx2(
      "svg",
      {
        xmlns: "http://www.w3.org/2000/svg",
        fill: "none",
        viewBox: "0 0 24 24",
        strokeWidth: "1.5",
        stroke: "currentColor",
        className: `${YouVisitIWC_default.icon} ${copied ? YouVisitIWC_default.iconSuccess : ""}`,
        children: copied ? /* @__PURE__ */ jsx2(
          "path",
          {
            strokeLinecap: "round",
            strokeLinejoin: "round",
            d: "M11.35 3.836c-.065.21-.1.433-.1.664 0 .414.336.75.75.75h4.5a.75.75 0 00.75-.75 2.25 2.25 0 00-.1-.664m-5.8 0A2.251 2.251 0 0113.5 2.25H15c1.012 0 1.867.668 2.15 1.586m-5.8 0c-.376.023-.75.05-1.124.08C9.095 4.01 8.25 4.973 8.25 6.108V8.25m8.9-4.414c.376.023.75.05 1.124.08 1.131.094 1.976 1.057 1.976 2.192V16.5A2.25 2.25 0 0118 18.75h-2.25m-7.5-10.5H4.875c-.621 0-1.125.504-1.125 1.125v11.25c0 .621.504 1.125 1.125 1.125h9.75c.621 0 1.125-.504 1.125-1.125V18.75m-7.5-10.5h6.375c.621 0 1.125.504 1.125 1.125v9.375m-8.25-3l1.5 1.5 3-3.75"
          }
        ) : /* @__PURE__ */ jsx2(
          "path",
          {
            strokeLinecap: "round",
            strokeLinejoin: "round",
            d: "M15.75 17.25v3.375c0 .621-.504 1.125-1.125 1.125h-9.75a1.125 1.125 0 01-1.125-1.125V7.875c0-.621.504-1.125 1.125-1.125H6.75a9.06 9.06 0 011.5.124m7.5 10.376h3.375c.621 0 1.125-.504 1.125-1.125V11.25c0-4.46-3.243-8.161-7.5-8.876a9.06 9.06 0 00-1.5-.124H9.375c-.621 0-1.125.504-1.125 1.125v3.5m7.5 10.375H9.375a1.125 1.125 0 01-1.125-1.125v-9.25m12 6.625v-1.875a3.375 3.375 0 00-3.375-3.375h-1.5a1.125 1.125 0 01-1.125-1.125v-1.5a3.375 3.375 0 00-3.375-3.375H9.75"
          }
        )
      }
    )
  ] }) });
};
var copy_to_clipboard_default = CopyToClipboard;

// src/YouVisitIWC/YouVisitIWC.tsx
import { Fragment, jsx as jsx3, jsxs as jsxs2 } from "react/jsx-runtime";
SyntaxHighlighter.registerLanguage("html", markup);
var YouVisitIWC = ({
  containerHeight = "300px",
  containerWidth = "100%",
  title = "Launch Experience",
  description = DEFAULT_DESCRIPTION,
  thumb,
  uploadDate = DEFAULT_UPLOAD_DATE,
  institution = 0,
  linkType = "immersive",
  location = 0,
  type = "inline-embed",
  stopId,
  hoverWidth = "90%",
  hoverHeight = "70%",
  iwcWidth = "100%",
  iwcHeight = "100%",
  showCode
}) => {
  const [isReady, setIsReady] = useState3(false);
  const jsonLdData = generateJsonLdData(title, description, thumb, uploadDate);
  const status = useScript(YV_SOURCE, {
    removeOnUnmount: false
  });
  useEffect2(() => {
    if (status === "ready" && typeof window !== "undefined" && window.YVScript) {
      window.YVScript.scanEmbeds();
      setIsReady(true);
    }
  }, [status]);
  const anchorProps = generateAnchorProps({
    title,
    institution,
    linkType,
    location,
    type,
    stopId,
    hoverWidth,
    hoverHeight,
    iwcWidth,
    iwcHeight
  });
  const dataAttributesString = generateDataAttributesString(anchorProps);
  const codeString = `<div style="height: ${containerHeight}; width: ${containerWidth}">
  <a alt="Launch Experience" href="https://www.youvisit.com/#/vte/
${dataAttributesString}">
    Virtual Tour
  </a>
</div>`;
  const codeString2 = `<script async="async" defer="defer" src="${YV_SOURCE}"></script>`;
  return /* @__PURE__ */ jsxs2(Fragment, { children: [
    /* @__PURE__ */ jsx3(
      "div",
      {
        className: `${YouVisitIWC_default.codeSnippetContainer}${isReady ? " ready" : ""}`,
        style: { width: containerWidth, height: containerHeight },
        children: /* @__PURE__ */ jsx3("a", { className: "virtualtour_embed", ...anchorProps, children: "Virtual Tour" })
      }
    ),
    showCode && /* @__PURE__ */ jsxs2(Fragment, { children: [
      /* @__PURE__ */ jsx3("h3", { children: "Place the HTML below anywhere on your page to display your IWC:" }),
      /* @__PURE__ */ jsxs2("div", { className: YouVisitIWC_default.codeSnippetContainer, children: [
        /* @__PURE__ */ jsx3("div", { className: YouVisitIWC_default.copyButtonContainer, children: /* @__PURE__ */ jsx3(copy_to_clipboard_default, { textData: codeString }) }),
        /* @__PURE__ */ jsx3(
          SyntaxHighlighter,
          {
            language: "html",
            style: coldarkCold,
            customStyle: {
              margin: "1rem 0",
              borderRadius: "4px",
              background: "#f5f5f5"
            },
            wrapLines: true,
            wrapLongLines: true,
            children: codeString.trim()
          }
        )
      ] }),
      /* @__PURE__ */ jsx3("h3", { children: "Place the script below anywhere on the same page as HTML above:" }),
      /* @__PURE__ */ jsxs2("div", { className: YouVisitIWC_default.codeSnippetContainer, children: [
        /* @__PURE__ */ jsx3("div", { className: YouVisitIWC_default.copyButtonContainer, children: /* @__PURE__ */ jsx3(copy_to_clipboard_default, { textData: codeString2 }) }),
        /* @__PURE__ */ jsx3(
          SyntaxHighlighter,
          {
            language: "html",
            style: coldarkCold,
            customStyle: {
              margin: "1rem 0",
              borderRadius: "4px",
              background: "#f5f5f5"
            },
            wrapLines: true,
            wrapLongLines: true,
            children: codeString2.trim()
          }
        )
      ] })
    ] }),
    /* @__PURE__ */ jsx3(JsonLd_default, { data: jsonLdData })
  ] });
};

// src/index.ts
var hello = () => {
  console.log("Hello from YouVisitIWC!");
};
export {
  YouVisitIWC,
  hello
};
//# sourceMappingURL=index.js.map